Method: TreeMap#first_entry

Defined in:
lib/tree_map/tree_map.rb

#first_entryObject

Returns a key-value mapping associated with the least key in this map, or null if the map is empty.



465
466
467
# File 'lib/tree_map/tree_map.rb', line 465

def first_entry
  root.first if root
end